"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class ContentApi extends base_api_1.BaseApi {
    createRelatedContentOnProcessInstance(processInstanceId, relatedContent, opts) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        (0, assert_1.throwIfNotDefined)(relatedContent, 'relatedContent');
        opts = opts || {};
        const pathParams = {
            processInstanceId
        };
        if (relatedContent instanceof model_1.RelatedContentRepresentation) {
            return this.post({
                path: '/api/enterprise/process-instances/{processInstanceId}/content',
                pathParams,
                queryParams: opts,
                bodyParam: relatedContent,
                returnType: model_1.RelatedContentRepresentation
            });
        }
        else {
            const formParams = {
                file: relatedContent
            };
            return this.post({
                path: '/api/enterprise/process-instances/{processInstanceId}/raw-content',
                pathParams,
                formParams,
                queryParams: opts,
                contentTypes: ['multipart/form-data'],
                returnType: model_1.RelatedContentRepresentation
            });
        }
    }
    createRelatedContentOnTask(taskId, relatedContent, opts) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        (0, assert_1.throwIfNotDefined)(relatedContent, 'relatedContent');
        const pathParams = {
            taskId
        };
        if (relatedContent instanceof model_1.RelatedContentRepresentation) {
            return this.post({
                path: '/api/enterprise/tasks/{taskId}/content',
                pathParams,
                queryParams: opts,
                bodyParam: relatedContent,
                returnType: model_1.RelatedContentRepresentation
            });
        }
        else {
            const formParams = {
                file: relatedContent
            };
            return this.post({
                path: '/api/enterprise/tasks/{taskId}/raw-content',
                pathParams,
                queryParams: opts,
                formParams,
                contentTypes: ['multipart/form-data'],
                returnType: model_1.RelatedContentRepresentation
            });
        }
    }
    createTemporaryRawRelatedContent(file) {
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const formParams = {
            file
        };
        return this.post({
            path: '/api/enterprise/content/raw',
            formParams,
            contentTypes: ['multipart/form-data'],
            returnType: model_1.RelatedContentRepresentation
        });
    }
    createTemporaryRelatedContent(relatedContent) {
        (0, assert_1.throwIfNotDefined)(relatedContent, 'relatedContent');
        return this.post({
            path: '/api/enterprise/content',
            bodyParam: relatedContent,
            returnType: model_1.RelatedContentRepresentation
        });
    }
    deleteContent(contentId) {
        (0, assert_1.throwIfNotDefined)(contentId, 'contentId');
        const pathParams = {
            contentId
        };
        return this.delete({
            path: '/api/enterprise/content/{contentId}',
            pathParams
        });
    }
    getContent(contentId) {
        (0, assert_1.throwIfNotDefined)(contentId, 'contentId');
        const pathParams = {
            contentId
        };
        return this.get({
            path: '/api/enterprise/content/{contentId}',
            pathParams,
            returnType: model_1.RelatedContentRepresentation
        });
    }
    getRawContentUrl(contentId) {
        return `${this.apiClient.basePath}/api/enterprise/content/${contentId}/raw`;
    }
    getRawContent(contentId, renditionType) {
        (0, assert_1.throwIfNotDefined)(contentId, 'contentId');
        if (renditionType) {
            const pathParams = {
                contentId,
                renditionType
            };
            return this.get({
                path: '/api/enterprise/content/{contentId}/rendition/{renditionType}',
                pathParams,
                returnType: 'blob',
                responseType: 'blob'
            });
        }
        else {
            const pathParams = {
                contentId
            };
            return this.get({
                path: '/api/enterprise/content/{contentId}/raw',
                pathParams,
                returnType: 'blob',
                responseType: 'blob'
            });
        }
    }
    getRelatedContentForProcessInstance(processInstanceId, opts) {
        (0, assert_1.throwIfNotDefined)(processInstanceId, 'processInstanceId');
        opts = opts || {};
        const pathParams = {
            processInstanceId
        };
        return this.get({
            path: '/api/enterprise/process-instances/{processInstanceId}/content',
            pathParams,
            queryParams: opts,
            returnType: model_1.ResultListDataRepresentationRelatedContentRepresentation
        });
    }
    getRelatedContentForTask(taskId, opts) {
        (0, assert_1.throwIfNotDefined)(taskId, 'taskId');
        const pathParams = {
            taskId
        };
        return this.get({
            path: '/api/enterprise/tasks/{taskId}/content',
            pathParams,
            queryParams: opts,
            returnType: model_1.ResultListDataRepresentationRelatedContentRepresentation
        });
    }
    getProcessesAndTasksOnContent(sourceId, source, size, page) {
        (0, assert_1.throwIfNotDefined)(sourceId, 'sourceId');
        (0, assert_1.throwIfNotDefined)(source, 'source');
        return this.get({
            path: '/api/enterprise/document-runtime',
            queryParams: {
                sourceId,
                source,
                size,
                page
            }
        });
    }
}
exports.ContentApi = ContentApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/content.api.js.map