"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelsApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
class ModelsApi extends base_api_1.BaseApi {
    createModel(modelRepresentation) {
        (0, assert_1.throwIfNotDefined)(modelRepresentation, 'modelRepresentation');
        return this.post({
            path: '/api/enterprise/models',
            bodyParam: modelRepresentation,
            returnType: model_1.ModelRepresentation
        });
    }
    deleteModel(modelId, opts) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        const queryParams = {
            cascade: opts === null || opts === void 0 ? void 0 : opts.cascade,
            deleteRuntimeApp: opts === null || opts === void 0 ? void 0 : opts.deleteRuntimeApp
        };
        return this.delete({
            path: '/api/enterprise/models/{modelId}',
            pathParams,
            queryParams
        });
    }
    duplicateModel(modelId, modelRepresentation) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(modelRepresentation, 'modelRepresentation');
        const pathParams = {
            modelId
        };
        return this.post({
            path: '/api/enterprise/models/{modelId}/clone',
            pathParams,
            bodyParam: modelRepresentation,
            returnType: model_1.ModelRepresentation
        });
    }
    getModelJSON(modelId) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        return this.get({
            path: '/api/enterprise/models/{modelId}/editor/json',
            pathParams
        });
    }
    getModelThumbnail(modelId) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        return this.get({
            path: '/api/enterprise/models/{modelId}/thumbnail',
            pathParams,
            accepts: ['image/png']
        });
    }
    getModel(modelId, opts) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const pathParams = {
            modelId
        };
        const queryParams = {
            includePermissions: opts === null || opts === void 0 ? void 0 : opts.includePermissions
        };
        return this.get({
            path: '/api/enterprise/models/{modelId}',
            pathParams,
            queryParams,
            returnType: model_1.ModelRepresentation
        });
    }
    getModelsToIncludeInAppDefinition() {
        return this.get({
            path: '/api/enterprise/models-for-app-definition',
            returnType: model_1.ResultListDataRepresentationModelRepresentation
        });
    }
    getModels(opts) {
        return this.get({
            path: '/api/enterprise/models',
            queryParams: opts,
            returnType: model_1.ResultListDataRepresentationModelRepresentation
        });
    }
    importNewVersion(modelId, file) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const pathParams = {
            modelId
        };
        const formParams = {
            file
        };
        return this.post({
            path: '/api/enterprise/models/{modelId}/newversion',
            pathParams,
            formParams,
            contentTypes: ['multipart/form-data'],
            returnType: model_1.ModelRepresentation
        });
    }
    importProcessModel(file) {
        (0, assert_1.throwIfNotDefined)(file, 'file');
        const formParams = {
            file
        };
        return this.post({
            path: '/api/enterprise/process-models/import',
            contentTypes: ['multipart/form-data'],
            formParams,
            returnType: model_1.ModelRepresentation
        });
    }
    saveModel(modelId, values) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(values, 'values');
        const pathParams = {
            modelId
        };
        return this.post({
            path: '/api/enterprise/models/{modelId}/editor/json',
            pathParams,
            bodyParam: values,
            returnType: model_1.ModelRepresentation
        });
    }
    updateModel(modelId, updatedModel) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        (0, assert_1.throwIfNotDefined)(updatedModel, 'updatedModel');
        const pathParams = {
            modelId
        };
        return this.put({
            path: '/api/enterprise/models/{modelId}',
            pathParams,
            bodyParam: updatedModel,
            returnType: model_1.ModelRepresentation
        });
    }
    validateModel(modelId, opts) {
        (0, assert_1.throwIfNotDefined)(modelId, 'modelId');
        const postBody = opts === null || opts === void 0 ? void 0 : opts.values;
        const pathParams = {
            modelId
        };
        return this.post({
            path: '/api/enterprise/models/{modelId}/editor/validate',
            pathParams,
            bodyParam: postBody,
            contentTypes: ['application/x-www-form-urlencoded']
        });
    }
}
exports.ModelsApi = ModelsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/activiti-rest-api/api/models.api.js.map