"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PeopleApi = void 0;
const model_1 = require("../model");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class PeopleApi extends base_api_1.BaseApi {
    createPerson(personBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(personBodyCreate, 'personBodyCreate');
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/people',
            queryParams,
            bodyParam: personBodyCreate,
            returnType: model_1.PersonEntry
        });
    }
    deleteAvatarImage(personId) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        return this.delete({
            path: '/people/{personId}/avatar',
            pathParams
        });
    }
    getAvatarImage(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment,
            placeholder: opts === null || opts === void 0 ? void 0 : opts.placeholder
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince
        };
        const accepts = ['application/octet-stream'];
        return this.get({
            path: '/people/{personId}/avatar',
            pathParams,
            queryParams,
            headerParams,
            accepts,
            returnType: 'blob'
        });
    }
    getPerson(personId, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        const pathParams = {
            personId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people/{personId}',
            pathParams,
            queryParams,
            returnType: model_1.PersonEntry
        });
    }
    listPeople(opts) {
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            orderBy: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.orderBy, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/people',
            queryParams,
            returnType: model_1.PersonPaging
        });
    }
    requestPasswordReset(personId, clientBody) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(clientBody, 'clientBody');
        const pathParams = {
            personId
        };
        return this.post({
            path: '/people/{personId}/request-password-reset',
            pathParams,
            bodyParam: clientBody
        });
    }
    resetPassword(personId, passwordResetBody) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(passwordResetBody, 'passwordResetBody');
        const pathParams = {
            personId
        };
        return this.post({
            path: '/people/{personId}/reset-password',
            pathParams,
            bodyParam: passwordResetBody
        });
    }
    updateAvatarImage(personId, contentBodyUpdate) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(contentBodyUpdate, 'contentBodyUpdate');
        const pathParams = {
            personId
        };
        const contentTypes = ['application/octet-stream'];
        return this.put({
            path: '/people/{personId}/avatar',
            pathParams,
            bodyParam: contentBodyUpdate,
            contentTypes
        });
    }
    updatePerson(personId, personBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(personId, 'personId');
        (0, assert_1.throwIfNotDefined)(personBodyUpdate, 'personBodyUpdate');
        const pathParams = {
            personId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/people/{personId}',
            pathParams,
            queryParams,
            bodyParam: personBodyUpdate,
            returnType: model_1.PersonEntry
        });
    }
}
exports.PeopleApi = PeopleApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/people.api.js.map