"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagsApi = void 0;
const tagEntry_1 = require("../model/tagEntry");
const tagPaging_1 = require("../model/tagPaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class TagsApi extends base_api_1.BaseApi {
    createTagForNode(nodeId, tagBodyCreate, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(tagBodyCreate, 'tagBodyCreate');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/nodes/{nodeId}/tags',
            pathParams,
            queryParams,
            bodyParam: tagBodyCreate,
            returnType: tagEntry_1.TagEntry
        });
    }
    deleteTagFromNode(nodeId, tagId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(tagId, 'tagId');
        const pathParams = {
            nodeId,
            tagId
        };
        return this.delete({
            path: '/nodes/{nodeId}/tags/{tagId}',
            pathParams
        });
    }
    getTag(tagId, opts) {
        (0, assert_1.throwIfNotDefined)(tagId, 'tagId');
        const pathParams = {
            tagId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/tags/{tagId}',
            pathParams,
            queryParams,
            returnType: tagEntry_1.TagEntry
        });
    }
    listTags(opts) {
        opts = opts || {};
        const pathParams = {};
        let where;
        if (opts === null || opts === void 0 ? void 0 : opts.tag) {
            where = opts.matching ? `(tag matches ('${opts.tag}'))` : `(tag='${opts.tag}')`;
        }
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv'),
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv'),
            where
        };
        return this.get({
            path: '/tags',
            pathParams,
            queryParams,
            returnType: tagPaging_1.TagPaging
        });
    }
    listTagsForNode(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            skipCount: opts === null || opts === void 0 ? void 0 : opts.skipCount,
            maxItems: opts === null || opts === void 0 ? void 0 : opts.maxItems,
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.get({
            path: '/nodes/{nodeId}/tags',
            pathParams,
            queryParams,
            returnType: tagPaging_1.TagPaging
        });
    }
    updateTag(tagId, tagBodyUpdate, opts) {
        (0, assert_1.throwIfNotDefined)(tagId, 'tagId');
        (0, assert_1.throwIfNotDefined)(tagBodyUpdate, 'tagBodyUpdate');
        const pathParams = {
            tagId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.put({
            path: '/tags/{tagId}',
            pathParams,
            queryParams,
            bodyParam: tagBodyUpdate,
            returnType: tagEntry_1.TagEntry
        });
    }
    deleteTag(tagId) {
        (0, assert_1.throwIfNotDefined)(tagId, 'tagId');
        const pathParams = {
            tagId
        };
        return this.delete({
            path: '/tags/{tagId}',
            pathParams
        });
    }
    createTags(tags) {
        (0, assert_1.throwIfNotDefined)(tags, 'tags');
        return this.post({
            path: '/tags',
            bodyParam: tags
        });
    }
    assignTagsToNode(nodeId, tags) {
        return this.post({
            path: '/nodes/{nodeId}/tags',
            pathParams: { nodeId },
            bodyParam: tags,
            returnType: tagPaging_1.TagPaging
        });
    }
    assignTagToNode(nodeId, tag) {
        return this.post({
            path: '/nodes/{nodeId}/tags',
            pathParams: { nodeId },
            bodyParam: tag,
            returnType: tagEntry_1.TagEntry
        });
    }
}
exports.TagsApi = TagsApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/tags.api.js.map