"use strict";
/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TrashcanApi = void 0;
const deletedNodeEntry_1 = require("../model/deletedNodeEntry");
const deletedNodesPaging_1 = require("../model/deletedNodesPaging");
const directAccessUrlEntry_1 = require("../model/directAccessUrlEntry");
const nodeEntry_1 = require("../model/nodeEntry");
const renditionEntry_1 = require("../model/renditionEntry");
const renditionPaging_1 = require("../model/renditionPaging");
const base_api_1 = require("./base.api");
const assert_1 = require("../../../assert");
const alfrescoApiClient_1 = require("../../../alfrescoApiClient");
class TrashcanApi extends base_api_1.BaseApi {
    deleteDeletedNode(nodeId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        return this.delete({
            path: '/deleted-nodes/{nodeId}',
            pathParams
        });
    }
    getArchivedNodeRendition(nodeId, renditionId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            nodeId,
            renditionId
        };
        return this.get({
            path: '/deleted-nodes/{nodeId}/renditions/{renditionId}',
            pathParams,
            returnType: renditionEntry_1.RenditionEntry
        });
    }
    getArchivedNodeRenditionContent(nodeId, renditionId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        opts = opts || {};
        const pathParams = {
            nodeId,
            renditionId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment,
            placeholder: opts === null || opts === void 0 ? void 0 : opts.placeholder
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince,
            Range: opts === null || opts === void 0 ? void 0 : opts.range
        };
        return this.get({
            path: '/deleted-nodes/{nodeId}/renditions/{renditionId}/content',
            pathParams,
            queryParams,
            headerParams,
            accepts: ['application/octet-stream']
        });
    }
    getDeletedNode(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv')
        };
        return this.get({
            path: '/deleted-nodes/{nodeId}',
            pathParams,
            queryParams,
            returnType: deletedNodeEntry_1.DeletedNodeEntry
        });
    }
    getDeletedNodeContent(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            attachment: opts === null || opts === void 0 ? void 0 : opts.attachment
        };
        const headerParams = {
            'If-Modified-Since': opts === null || opts === void 0 ? void 0 : opts.ifModifiedSince,
            Range: opts === null || opts === void 0 ? void 0 : opts.range
        };
        const accepts = ['application/octet-stream'];
        return this.get({
            path: '/deleted-nodes/{nodeId}/content',
            pathParams,
            queryParams,
            headerParams,
            accepts,
            returnType: 'blob'
        });
    }
    listDeletedNodeRenditions(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            where: opts === null || opts === void 0 ? void 0 : opts.where
        };
        return this.get({
            path: '/deleted-nodes/{nodeId}/renditions',
            pathParams,
            queryParams,
            returnType: renditionPaging_1.RenditionPaging
        });
    }
    listDeletedNodes(opts) {
        const queryParams = Object.assign(Object.assign({}, (opts || {})), { include: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.include, 'csv') });
        return this.get({
            path: '/deleted-nodes',
            queryParams,
            returnType: deletedNodesPaging_1.DeletedNodesPaging
        });
    }
    restoreDeletedNode(nodeId, opts) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        const queryParams = {
            fields: (0, alfrescoApiClient_1.buildCollectionParam)(opts === null || opts === void 0 ? void 0 : opts.fields, 'csv')
        };
        return this.post({
            path: '/deleted-nodes/{nodeId}/restore',
            pathParams,
            queryParams,
            bodyParam: opts === null || opts === void 0 ? void 0 : opts.deletedNodeBodyRestore,
            returnType: nodeEntry_1.NodeEntry
        });
    }
    requestDirectAccessUrl(nodeId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        const pathParams = {
            nodeId
        };
        return this.post({
            path: '/deleted-nodes/{nodeId}/request-direct-access-url',
            pathParams,
            returnType: directAccessUrlEntry_1.DirectAccessUrlEntry
        });
    }
    requestRenditionDirectAccessUrl(nodeId, renditionId) {
        (0, assert_1.throwIfNotDefined)(nodeId, 'nodeId');
        (0, assert_1.throwIfNotDefined)(renditionId, 'renditionId');
        const pathParams = {
            nodeId,
            renditionId
        };
        return this.post({
            path: '/deleted-nodes/{nodeId}/renditions/{renditionId}/request-direct-access-url',
            pathParams,
            returnType: directAccessUrlEntry_1.DirectAccessUrlEntry
        });
    }
}
exports.TrashcanApi = TrashcanApi;
//# sourceMappingURL=../../../../../../../lib/js-api/src/api/content-rest-api/api/trashcan.api.js.map