/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ModelRepresentation, ObjectNode, ResultListDataRepresentationModelRepresentation, ValidationErrorRepresentation } from '../model';
import { BaseApi } from './base.api';
export interface GetModelsQuery {
    filter?: string;
    sort?: string;
    modelType?: number;
    referenceId?: number;
}
/**
 * Models service.
 */
export declare class ModelsApi extends BaseApi {
    /**
     * Create a new model
     * @param modelRepresentation modelRepresentation
     * @return Promise<ModelRepresentation>
     */
    createModel(modelRepresentation: ModelRepresentation): Promise<ModelRepresentation>;
    /**
     * Delete a model
     * @param modelId modelId
     * @param opts Optional parameters
     * @param opts.cascade cascade
     * @param opts.deleteRuntimeApp deleteRuntimeApp
     * @return Promise<{}>
     */
    deleteModel(modelId: number, opts?: {
        cascade?: boolean;
        deleteRuntimeApp?: boolean;
    }): Promise<any>;
    /**
     * Duplicate an existing model
     * @param modelId modelId
     * @param modelRepresentation modelRepresentation
     * @return Promise<ModelRepresentation>
     */
    duplicateModel(modelId: number, modelRepresentation: ModelRepresentation): Promise<ModelRepresentation>;
    /**
     * Get model content
     * @param modelId modelId
     * @return Promise<ObjectNode>
     */
    getModelJSON(modelId: number): Promise<ObjectNode>;
    /**
     * Get a model's thumbnail image
     * @param modelId modelId
     * @return Promise<string>
     */
    getModelThumbnail(modelId: number): Promise<string>;
    /**
     * Get a model
     *
     * Models act as containers for process, form, decision table and app definitions
     * @param modelId modelId
     * @param opts Optional parameters
     * @return Promise<ModelRepresentation>
     */
    getModel(modelId: number, opts?: {
        includePermissions?: boolean;
    }): Promise<ModelRepresentation>;
    /**
     * List process definition models shared with the current user
     * @return Promise<ResultListDataRepresentationModelRepresentation>
     */
    getModelsToIncludeInAppDefinition(): Promise<ResultListDataRepresentationModelRepresentation>;
    /**
     * List models (process, form, decision rule or app)
     * @param opts Optional parameters
     * @return Promise<ResultListDataRepresentationModelRepresentation>
     */
    getModels(opts?: GetModelsQuery): Promise<ResultListDataRepresentationModelRepresentation>;
    /**
     * Create a new version of a model
     * @param modelId modelId
     * @param file file
     * @return Promise<ModelRepresentation>
     */
    importNewVersion(modelId: number, file: any): Promise<ModelRepresentation>;
    /**
     * Import a BPMN 2.0 XML file
     * @param file file
     * @return Promise<ModelRepresentation>
     */
    importProcessModel(file: any): Promise<ModelRepresentation>;
    /**
     * Update model content
     * @param modelId modelId
     * @param values values
     * @return Promise<ModelRepresentation>
     */
    saveModel(modelId: number, values: any): Promise<ModelRepresentation>;
    /**
     * Update a model
     *
     * This method allows you to update the metadata of a model. In order to update the content of the model you will need to call the specific endpoint for that model type.
     * @param modelId modelId
     * @param updatedModel updatedModel
     * @return Promise<ModelRepresentation>
     */
    updateModel(modelId: number, updatedModel: ModelRepresentation): Promise<ModelRepresentation>;
    /**
     * Validate model content
     * @param modelId modelId
     * @param opts Optional parameters
     * @param opts.values values
     * @return Promise<ValidationErrorRepresentation>
     */
    validateModel(modelId: number, opts?: {
        values?: any;
    }): Promise<ValidationErrorRepresentation>;
}
