/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { HistoricTaskInstanceQueryRepresentation, IdentityLinkRepresentation, ResultListDataRepresentationTaskRepresentation, TaskAuditInfoRepresentation, TaskFilterRequestRepresentation, TaskQueryRepresentation, TaskRepresentation, TaskUpdateRepresentation } from '../model';
import { BaseApi } from './base.api';
/**
 * Tasks service.
 */
export declare class TasksApi extends BaseApi {
    /**
     * List the users and groups involved with a task
     * @param taskId taskId
     * @param identityLinkRepresentation identityLinkRepresentation
     * @returns Promise<IdentityLinkRepresentation>
     */
    createIdentityLink(taskId: string, identityLinkRepresentation: IdentityLinkRepresentation): Promise<IdentityLinkRepresentation>;
    /**
     * Create a standalone task
     *
     * A standalone task is one which is not associated with any process instance.
     * @param taskRepresentation taskRepresentation
     * @returns Promise<TaskRepresentation>
     */
    createNewTask(taskRepresentation: TaskRepresentation): Promise<TaskRepresentation>;
    /**
     * Remove a user or group involvement from a task
     * @param taskId taskId
     * @param family family
     * @param identityId identityId
     * @param type type
     * @returns Promise<{}>
     */
    deleteIdentityLink(taskId: string, family: string, identityId: string, type: string): Promise<any>;
    /**
     * Delete a task
     * @param taskId taskId
     * @returns Promise<{}>
     */
    deleteTask(taskId: string): Promise<void>;
    /**
     * Filter a list of tasks
     * @param tasksFilter tasksFilter
     * @returns Promise<ResultListDataRepresentationTaskRepresentation>
     */
    filterTasks(tasksFilter: TaskFilterRequestRepresentation): Promise<ResultListDataRepresentationTaskRepresentation>;
    /**
     * Get a user or group involvement with a task
     * @param taskId taskId
     * @param family family
     * @param identityId identityId
     * @param type type
     * @returns Promise<IdentityLinkRepresentation>
     */
    getIdentityLinkType(taskId: string, family: string, identityId: string, type: string): Promise<IdentityLinkRepresentation>;
    /**
     * List either the users or groups involved with a process instance
     * @param taskId taskId
     * @param family family
     * @returns Promise<IdentityLinkRepresentation>
     */
    getIdentityLinksForFamily(taskId: string, family: string): Promise<IdentityLinkRepresentation>;
    /**
     * getIdentityLinks
     * @param taskId taskId
     * @returns Promise<IdentityLinkRepresentation>
     */
    getIdentityLinks(taskId: string): Promise<IdentityLinkRepresentation>;
    /**
     * Get the audit log for a task
     * @param taskId taskId
     * @returns Promise<TaskAuditInfoRepresentation>
     */
    getTaskAuditLog(taskId: string): Promise<TaskAuditInfoRepresentation>;
    /**
     * Get the audit log for a task
     * @param taskId taskId
     * @returns Promise<Blob> task audit in blob
     */
    getTaskAuditPdf(taskId: string): Promise<Blob>;
    /**
     * Get a task
     * @param taskId taskId
     * @returns Promise<TaskRepresentation>
     */
    getTask(taskId: string): Promise<TaskRepresentation>;
    /**
     * Query historic tasks
     * @param queryRequest queryRequest
     * @returns Promise<ResultListDataRepresentationTaskRepresentation>
     */
    listHistoricTasks(queryRequest: HistoricTaskInstanceQueryRepresentation): Promise<ResultListDataRepresentationTaskRepresentation>;
    /**
     * List tasks
     * @param tasksQuery tasksQuery
     * @returns Promise<ResultListDataRepresentationTaskRepresentation>
     */
    listTasks(tasksQuery: TaskQueryRepresentation): Promise<ResultListDataRepresentationTaskRepresentation>;
    /**
     * Update a task
     *
     * You can edit only name, description and dueDate (ISO 8601 string).
     * @param taskId taskId
     * @param updated updated
     * @returns Promise<TaskRepresentation>
     */
    updateTask(taskId: string, updated: TaskUpdateRepresentation): Promise<TaskRepresentation>;
}
