/*!
 * @license
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { BaseApi } from './base.api';
import { ContentPagingQuery } from '../../content-rest-api';
import { BulkAssignHoldResponseEntry, HoldBody, HoldEntry, HoldPaging } from './../model';
import { RequestQuery } from '../../search-rest-api';
import { HoldBulkStatusEntry } from '../model/holdBulkStatusEntry';
/**
 * Legal Holds service.
 * @module LegalHoldApi
 */
export declare class LegalHoldApi extends BaseApi {
    /**
     * List of legal holds
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param options Optional parameters
     * @returns Promise<HoldPaging>
     */
    getHolds(filePlanId?: string, options?: ContentPagingQuery): Promise<HoldPaging>;
    /**
     * Assign node to legal hold
     * @param holdId The identifier of a hold
     * @param nodeId The id of the node to be assigned to existing hold
     * @returns Promise<HoldEntry>
     */
    assignHold(nodeId: string, holdId: string): Promise<HoldEntry>;
    /**
     * Assign nodes to legal hold
     * @param holdId The identifier of a hold
     * @param nodeIds The list with id of nodes to assign to existing hold
     * @returns Promise<HoldPaging>
     */
    assignHolds(nodeIds: {
        id: string;
    }[], holdId: string): Promise<HoldPaging>;
    /**
     * Deletes the relationship between a child with id nodeId and a parent hold with id holdId
     * @param holdId The identifier of a hold
     * @param nodeId The Id of the node which is unassigned
     * @returns Empty response
     */
    unassignHold(holdId: string, nodeId: string): Promise<void>;
    /**
     * Create new hold
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param hold Hold to create
     * @returns Promise<HoldEntry>
     */
    createHold(filePlanId: string, hold: HoldBody): Promise<HoldEntry>;
    /**
     * Create list of new holds
     * @param filePlanId The identifier of a file plan. You can also use the -filePlan- alias.
     * @param holds Array of holds
     * @returns Promise<HoldPaging>
     */
    createHolds(filePlanId: string, holds: HoldBody[]): Promise<HoldPaging>;
    /**
     * Start the asynchronous bulk process for a hold with id holdId based on search query results.
     * @param holdId The identifier of a hold
     * @param query Search query
     * @returns Promise<BulkAssignHoldResponseEntry>
     */
    bulkAssignHold(holdId: string, query: RequestQuery): Promise<BulkAssignHoldResponseEntry>;
    /**
     * Get status of bulk operation with **bulkStatusId** for **holdId**.
     * @param bulkStatusId The identifier of a bulk status
     * @param holdId The identifier of a hold
     * @returns Promise<HoldsBulkStatusEntry>
     */
    getBulkStatus(bulkStatusId: string, holdId: string): Promise<HoldBulkStatusEntry>;
}
